#include "program.h"

Program::Program(QString n, QList<Exercise> e)
{
    name = n;
    exercises = e;
}

QString Program::getName()
{
    return name;
}

QStringList Program::getExerciseNames()
{
    QStringList list;

    for(int i = 0; i < exercises.count();i++)
    {
        Exercise e = exercises.at(i);
        list.append(e.getName());
    }

    return list;
}
